==> bigloo2.9a.tar.gz: bigloo2.9a/comptime/Read/reader.c <==
/*===========================================================================*/
/*   (Read/reader.scm)                                                       */
/*   Bigloo (2.9a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Dec 25 07:31:22 CET 2006        */
/*===========================================================================*/
/* COMPILATION: (/users/serrano/prgm/project/bigloo/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /users/serrano/prgm/project/bigloo/lib/2.9a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -indent Read/reader.scm)*/
/* GC selection */
#define THE_GC BOEHM_GC

#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif

/* Object type definitions */
	typedef struct BgL_z62processzd2exceptionzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                *BgL_z62processzd2exceptionzb0_bglt;

	typedef struct BgL_z62iozd2parsezd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                               *BgL_z62iozd2parsezd2errorz62_bglt;

	typedef struct BgL_z62iozd2writezd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                               *BgL_z62iozd2writezd2errorz62_bglt;

	typedef struct BgL_z62iozd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                       *BgL_z62iozd2errorzb0_bglt;

	typedef struct BgL_z62iozd2readzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                              *BgL_z62iozd2readzd2errorz62_bglt;

	typedef struct BgL_z62typezd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
		obj_t BgL_typez00;
	}                         *BgL_z62typezd2errorzb0_bglt;

	typedef struct BgL_z62errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                  *BgL_z62errorz62_bglt;

	typedef struct BgL_z62iozd2portzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                              *BgL_z62iozd2portzd2errorz62_bglt;

	typedef struct BgL_z62iozd2malformedzd2urlzd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                        
		*BgL_z62iozd2malformedzd2urlzd2errorzb0_bglt;

	typedef struct BgL_z62iozd2filezd2notzd2foundzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                           
		*BgL_z62iozd2filezd2notzd2foundzd2errorz62_bglt;

	typedef struct BgL_z62iozd2sigpipezd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                 *BgL_z62iozd2sigpipezd2errorz62_bglt;

	typedef struct BgL_z62iozd2unknownzd2hostzd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                       
		*BgL_z62iozd2unknownzd2hostzd2errorzb0_bglt;

	typedef struct BgL_z62exceptionz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
	}                      *BgL_z62exceptionz62_bglt;

	typedef struct BgL_z62evalzd2warningzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_argsz00;
	}                           *BgL_z62evalzd2warningzb0_bglt;

	typedef struct BgL_z62iozd2timeoutzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                 *BgL_z62iozd2timeoutzd2errorz62_bglt;

	typedef struct BgL_z62warningz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_argsz00;
	}                    *BgL_z62warningz62_bglt;

	typedef struct BgL_z62iozd2closedzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                *BgL_z62iozd2closedzd2errorz62_bglt;

	typedef struct BgL_tarzd2headerzd2_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_namez00;
		long BgL_modez00;
		long BgL_uidz00;
		long BgL_gidz00;
		long BgL_siza7eza7;
		obj_t BgL_mtimez00;
		long BgL_checksumz00;
		obj_t BgL_typez00;
		obj_t BgL_linknamez00;
		obj_t BgL_magicz00;
		obj_t BgL_unamez00;
		obj_t BgL_gnamez00;
		long BgL_devmajorz00;
		long BgL_devminorz00;
	}                      *BgL_tarzd2headerzd2_bglt;


	BGL_IMPORT obj_t open_input_string(obj_t);
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	static obj_t BGl_requirezd2initializa7ationz75zzread_readerz00 = BUNSPEC;
	static obj_t BGl_cnstzd2initzd2zzread_readerz00();
	static obj_t BGl_importedzd2moduleszd2initz00zzread_readerz00();
	BGL_IMPORT obj_t BGl_errorz00zz__errorz00(obj_t, obj_t, obj_t);
	static obj_t BGl__compilerzd2readzd2zzread_readerz00(obj_t, obj_t);
	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzread_readerz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__errorz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__intextz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_EXPORTED_DECL obj_t BGl_compilerzd2readzd2zzread_readerz00(obj_t);
	extern obj_t BGl_za2readerza2z00zzengine_paramz00;
	BGL_IMPORT obj_t string_to_obj(obj_t);
	static obj_t BGl_libraryzd2moduleszd2initz00zzread_readerz00();
	static obj_t BGl_methodzd2initzd2zzread_readerz00();
	static obj_t __cnst[1];


	   
		 
		DEFINE_STRING(BGl_string1277z00zzread_readerz00,
		BgL_bgl_string1277za700za7za7r1283za7, "", 0);
	      DEFINE_STRING(BGl_string1278z00zzread_readerz00,
		BgL_bgl_string1278za700za7za7r1284za7, "Illegal intern value", 20);
	      DEFINE_STRING(BGl_string1280z00zzread_readerz00,
		BgL_bgl_string1280za700za7za7r1285za7, "intern ", 7);
	      DEFINE_STRING(BGl_string1279z00zzread_readerz00,
		BgL_bgl_string1279za700za7za7r1286za7, "read_reader", 11);
	     
		DEFINE_EXPORT_BGL_PROCEDURE(BGl_compilerzd2readzd2envz00zzread_readerz00,
		BgL_bgl__compilerza7d2read1287za7, va_generic_entry,
		BGl__compilerzd2readzd2zzread_readerz00, BUNSPEC, -1);
	BGL_IMPORT obj_t BGl_readzd2envzd2zz__readerz00;



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzread_readerz00(long
		BgL_checksumz00_46, char *BgL_fromz00_47)
	{
		AN_OBJECT;
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzread_readerz00))
				{
					BGl_requirezd2initializa7ationz75zzread_readerz00 =
						BBOOL(((bool_t) 0));
					BGl_libraryzd2moduleszd2initz00zzread_readerz00();
					BGl_cnstzd2initzd2zzread_readerz00();
					BGl_importedzd2moduleszd2initz00zzread_readerz00();
					return BUNSPEC;
				}
			else
				{
					return BUNSPEC;
				}
		}
	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			BGl_modulezd2initializa7ationz75zz__readerz00(((long) 0), "read_reader");
			BGl_modulezd2initializa7ationz75zz__errorz00(((long) 0), "read_reader");
			BGl_modulezd2initializa7ationz75zz__intextz00(((long) 0), "read_reader");
			return BUNSPEC;
		}
	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			{	/* Read/reader.scm 16 */
				obj_t BgL_cportz00_38;

				BgL_cportz00_38 = open_input_string(BGl_string1280z00zzread_readerz00);
				{
					long BgL_iz00_39;

					BgL_iz00_39 = ((long) 0);
				BgL_loopz00_40:
					if ((BgL_iz00_39 == ((long) -1)))
						{	/* Read/reader.scm 16 */
							return BUNSPEC;
						}
					else
						{	/* Read/reader.scm 16 */
							{	/* Read/reader.scm 16 */
								obj_t BgL_arg1282z00_42;

								{	/* Read/reader.scm 16 */

									{	/* Read/reader.scm 16 */
										obj_t BgL_locationz00_44;

										BgL_locationz00_44 = BBOOL(((bool_t) 0));
										{	/* Read/reader.scm 16 */

											BgL_arg1282z00_42 =
												BGl_readz00zz__readerz00(BgL_cportz00_38,
												BgL_locationz00_44);
										}
									}
								}
								{	/* Read/reader.scm 16 */
									int BgL_auxz00_62;

									BgL_auxz00_62 = (int) (BgL_iz00_39);
									CNST_TABLE_SET(BgL_auxz00_62, BgL_arg1282z00_42);
							}}
							{	/* Read/reader.scm 16 */
								int BgL_auxz00_45;

								BgL_auxz00_45 = (int) ((BgL_iz00_39 - ((long) 1)));
								{
									long BgL_iz00_67;

									BgL_iz00_67 = (long) (BgL_auxz00_45);
									BgL_iz00_39 = BgL_iz00_67;
									goto BgL_loopz00_40;
								}
							}
						}
				}
			}
		}
	}



/* compiler-read */
	BGL_EXPORTED_DEF obj_t BGl_compilerzd2readzd2zzread_readerz00(obj_t
		BgL_argsz00_1)
	{
		AN_OBJECT;
		{	/* Read/reader.scm 23 */
			{	/* Read/reader.scm 24 */
				obj_t BgL_valuez00_27;

				BgL_valuez00_27 = apply(BGl_readzd2envzd2zz__readerz00, BgL_argsz00_1);
				if (
					(BGl_za2readerza2z00zzengine_paramz00 == CNST_TABLE_REF(((long) 0))))
					{	/* Read/reader.scm 25 */
						if (EOF_OBJECTP(BgL_valuez00_27))
							{	/* Read/reader.scm 27 */
								return BgL_valuez00_27;
							}
						else
							{	/* Read/reader.scm 27 */
								if (STRINGP(BgL_valuez00_27))
									{	/* Read/reader.scm 29 */
										return string_to_obj(BgL_valuez00_27);
									}
								else
									{	/* Read/reader.scm 29 */
										return
											BGl_errorz00zz__errorz00
											(BGl_string1277z00zzread_readerz00,
											BGl_string1278z00zzread_readerz00, BgL_valuez00_27);
									}
							}
					}
				else
					{	/* Read/reader.scm 25 */
						return BgL_valuez00_27;
					}
			}
		}
	}



/* _compiler-read */
	obj_t BGl__compilerzd2readzd2zzread_readerz00(obj_t BgL_envz00_33,
		obj_t BgL_argsz00_34)
	{
		AN_OBJECT;
		{	/* Read/reader.scm 23 */
			return BGl_compilerzd2readzd2zzread_readerz00(BgL_argsz00_34);
		}
	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			return BUNSPEC;
		}
	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			return
				BGl_modulezd2initializa7ationz75zzengine_paramz00(((long) 514705515),
				BSTRING_TO_STRING(BGl_string1279z00zzread_readerz00));
		}
	}

#ifdef __cplusplus
}
#endif

==> bigloo3.1a.tar.gz: bigloo3.1a/comptime/Read/reader.c <==
/*===========================================================================*/
/*   (Read/reader.scm)                                                       */
/*   Bigloo (3.1a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Wed May 28 08:14:44 CEST 2008       */
/*===========================================================================*/
/* COMPILATION: (/users/serrano/prgm/project/bigloo/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /users/serrano/prgm/project/bigloo/lib/3.1a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -indent Read/reader.scm)*/
/* GC selection */
#define THE_GC BOEHM_GC

#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif

/* Object type definitions */
	typedef struct BgL_z62processzd2exceptionzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                *BgL_z62processzd2exceptionzb0_bglt;

	typedef struct BgL_z62iozd2parsezd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                               *BgL_z62iozd2parsezd2errorz62_bglt;

	typedef struct BgL_z62iozd2writezd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                               *BgL_z62iozd2writezd2errorz62_bglt;

	typedef struct BgL_z62iozd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                       *BgL_z62iozd2errorzb0_bglt;

	typedef struct BgL_threadzd2backendzd2_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_namez00;
	}                          *BgL_threadzd2backendzd2_bglt;

	typedef struct BgL_z62iozd2readzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                              *BgL_z62iozd2readzd2errorz62_bglt;

	typedef struct BgL_z62typezd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
		obj_t BgL_typez00;
	}                         *BgL_z62typezd2errorzb0_bglt;

	typedef struct BgL_z62errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                  *BgL_z62errorz62_bglt;

	typedef struct BgL_z62iozd2portzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                              *BgL_z62iozd2portzd2errorz62_bglt;

	typedef struct BgL_z62securityzd2exceptionzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_messagez00;
	}                                 *BgL_z62securityzd2exceptionzb0_bglt;

	typedef struct BgL_z62iozd2malformedzd2urlzd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                        
		*BgL_z62iozd2malformedzd2urlzd2errorzb0_bglt;

	typedef struct BgL_z62iozd2filezd2notzd2foundzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                           
		*BgL_z62iozd2filezd2notzd2foundzd2errorz62_bglt;

	typedef struct BgL_z62iozd2sigpipezd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                 *BgL_z62iozd2sigpipezd2errorz62_bglt;

	typedef struct BgL_z62accesszd2controlzd2exceptionz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_messagez00;
		obj_t BgL_permissionz00;
	}                                        
		*BgL_z62accesszd2controlzd2exceptionz62_bglt;

	typedef struct BgL_threadz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_namez00;
	}                *BgL_threadz00_bglt;

	typedef struct BgL_z62iozd2unknownzd2hostzd2errorzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                       
		*BgL_z62iozd2unknownzd2hostzd2errorzb0_bglt;

	typedef struct BgL_z62exceptionz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
	}                      *BgL_z62exceptionz62_bglt;

	typedef struct BgL_z62conditionz62_bgl
	{
		header_t header;
		obj_t widening;
	}                      *BgL_z62conditionz62_bglt;

	typedef struct BgL_z62evalzd2warningzb0_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_argsz00;
	}                           *BgL_z62evalzd2warningzb0_bglt;

	typedef struct BgL_z62iozd2timeoutzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                 *BgL_z62iozd2timeoutzd2errorz62_bglt;

	typedef struct BgL_z62warningz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_argsz00;
	}                    *BgL_z62warningz62_bglt;

	typedef struct BgL_z62iozd2closedzd2errorz62_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_fnamez00;
		obj_t BgL_locationz00;
		obj_t BgL_procz00;
		obj_t BgL_msgz00;
		obj_t BgL_objz00;
	}                                *BgL_z62iozd2closedzd2errorz62_bglt;

	typedef struct BgL_tarzd2headerzd2_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_namez00;
		long BgL_modez00;
		long BgL_uidz00;
		long BgL_gidz00;
		long BgL_siza7eza7;
		obj_t BgL_mtimez00;
		long BgL_checksumz00;
		obj_t BgL_typez00;
		obj_t BgL_linknamez00;
		obj_t BgL_magicz00;
		obj_t BgL_unamez00;
		obj_t BgL_gnamez00;
		long BgL_devmajorz00;
		long BgL_devminorz00;
	}                      *BgL_tarzd2headerzd2_bglt;


	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	static obj_t BGl_requirezd2initializa7ationz75zzread_readerz00 = BUNSPEC;
	static obj_t BGl_cnstzd2initzd2zzread_readerz00();
	static obj_t BGl_importedzd2moduleszd2initz00zzread_readerz00();
	BGL_IMPORT obj_t BGl_errorz00zz__errorz00(obj_t, obj_t, obj_t);
	static obj_t BGl__compilerzd2readzd2zzread_readerz00(obj_t, obj_t);
	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzread_readerz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__intextz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__errorz00(long, char *);
	BGL_EXPORTED_DECL obj_t BGl_compilerzd2readzd2zzread_readerz00(obj_t);
	BGL_IMPORT obj_t bgl_open_input_string(obj_t, int);
	extern obj_t BGl_za2readerza2z00zzengine_paramz00;
	BGL_IMPORT obj_t string_to_obj(obj_t);
	static obj_t BGl_libraryzd2moduleszd2initz00zzread_readerz00();
	static obj_t BGl_methodzd2initzd2zzread_readerz00();
	static obj_t __cnst[1];


	   
		 
		DEFINE_STRING(BGl_string1326z00zzread_readerz00,
		BgL_bgl_string1326za700za7za7r1332za7, "", 0);
	      DEFINE_STRING(BGl_string1327z00zzread_readerz00,
		BgL_bgl_string1327za700za7za7r1333za7, "Illegal intern value", 20);
	      DEFINE_STRING(BGl_string1328z00zzread_readerz00,
		BgL_bgl_string1328za700za7za7r1334za7, "read_reader", 11);
	      DEFINE_STRING(BGl_string1329z00zzread_readerz00,
		BgL_bgl_string1329za700za7za7r1335za7, "intern ", 7);
	     
		DEFINE_EXPORT_BGL_PROCEDURE(BGl_compilerzd2readzd2envz00zzread_readerz00,
		BgL_bgl__compilerza7d2read1336za7, va_generic_entry,
		BGl__compilerzd2readzd2zzread_readerz00, BUNSPEC, -1);
	BGL_IMPORT obj_t BGl_readzd2envzd2zz__readerz00;



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzread_readerz00(long
		BgL_checksumz00_58, char *BgL_fromz00_59)
	{
		AN_OBJECT;
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzread_readerz00))
				{
					BGl_requirezd2initializa7ationz75zzread_readerz00 =
						BBOOL(((bool_t) 0));
					BGl_libraryzd2moduleszd2initz00zzread_readerz00();
					BGl_cnstzd2initzd2zzread_readerz00();
					BGl_importedzd2moduleszd2initz00zzread_readerz00();
					return BUNSPEC;
				}
			else
				{
					return BUNSPEC;
				}
		}
	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			BGl_modulezd2initializa7ationz75zz__readerz00(((long) 0), "read_reader");
			BGl_modulezd2initializa7ationz75zz__errorz00(((long) 0), "read_reader");
			BGl_modulezd2initializa7ationz75zz__intextz00(((long) 0), "read_reader");
			return BUNSPEC;
		}
	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			{	/* Read/reader.scm 16 */
				obj_t BgL_cportz00_50;

				BgL_cportz00_50 =
					bgl_open_input_string(BGl_string1329z00zzread_readerz00,
					(int) (((long) 0)));
				{
					long BgL_iz00_51;

					BgL_iz00_51 = ((long) 0);
				BgL_loopz00_52:
					if ((BgL_iz00_51 == ((long) -1)))
						{	/* Read/reader.scm 16 */
							return BUNSPEC;
						}
					else
						{	/* Read/reader.scm 16 */
							{	/* Read/reader.scm 16 */
								obj_t BgL_arg1331z00_54;

								{	/* Read/reader.scm 16 */

									{	/* Read/reader.scm 16 */
										obj_t BgL_locationz00_56;

										BgL_locationz00_56 = BBOOL(((bool_t) 0));
										{	/* Read/reader.scm 16 */

											BgL_arg1331z00_54 =
												BGl_readz00zz__readerz00(BgL_cportz00_50,
												BgL_locationz00_56);
										}
									}
								}
								{	/* Read/reader.scm 16 */
									int BgL_auxz00_75;

									BgL_auxz00_75 = (int) (BgL_iz00_51);
									CNST_TABLE_SET(BgL_auxz00_75, BgL_arg1331z00_54);
							}}
							{	/* Read/reader.scm 16 */
								int BgL_auxz00_57;

								BgL_auxz00_57 = (int) ((BgL_iz00_51 - ((long) 1)));
								{
									long BgL_iz00_80;

									BgL_iz00_80 = (long) (BgL_auxz00_57);
									BgL_iz00_51 = BgL_iz00_80;
									goto BgL_loopz00_52;
								}
							}
						}
				}
			}
		}
	}



/* compiler-read */
	BGL_EXPORTED_DEF obj_t BGl_compilerzd2readzd2zzread_readerz00(obj_t
		BgL_argsz00_1)
	{
		AN_OBJECT;
		{	/* Read/reader.scm 23 */
			{	/* Read/reader.scm 24 */
				obj_t BgL_valuez00_39;

				BgL_valuez00_39 = apply(BGl_readzd2envzd2zz__readerz00, BgL_argsz00_1);
				if (
					(BGl_za2readerza2z00zzengine_paramz00 == CNST_TABLE_REF(((long) 0))))
					{	/* Read/reader.scm 25 */
						if (EOF_OBJECTP(BgL_valuez00_39))
							{	/* Read/reader.scm 27 */
								return BgL_valuez00_39;
							}
						else
							{	/* Read/reader.scm 27 */
								if (STRINGP(BgL_valuez00_39))
									{	/* Read/reader.scm 29 */
										return string_to_obj(BgL_valuez00_39);
									}
								else
									{	/* Read/reader.scm 29 */
										return
											BGl_errorz00zz__errorz00
											(BGl_string1326z00zzread_readerz00,
											BGl_string1327z00zzread_readerz00, BgL_valuez00_39);
									}
							}
					}
				else
					{	/* Read/reader.scm 25 */
						return BgL_valuez00_39;
					}
			}
		}
	}



/* _compiler-read */
	obj_t BGl__compilerzd2readzd2zzread_readerz00(obj_t BgL_envz00_45,
		obj_t BgL_argsz00_46)
	{
		AN_OBJECT;
		{	/* Read/reader.scm 23 */
			return BGl_compilerzd2readzd2zzread_readerz00(BgL_argsz00_46);
		}
	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			return BUNSPEC;
		}
	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzread_readerz00()
	{
		AN_OBJECT;
		{	/* Read/reader.scm 16 */
			return
				BGl_modulezd2initializa7ationz75zzengine_paramz00(((long) 109675922),
				BSTRING_TO_STRING(BGl_string1328z00zzread_readerz00));
		}
	}

#ifdef __cplusplus
}
#endif
